==> advert-1.2.4-sources.jar: com/yodo1/advert/utils/YPermissonUtils.java <==
package com.yodo1.advert.utils;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;
import android.support.v4.app.ActivityCompat;

/**
 * 权限检查及动态权限申请
 * Created by yodo1 on 2016/3/17.
 */
public class YPermissonUtils {
    private static String[] permissions = {Manifest.permission.READ_PHONE_STATE };

    private static  int requestCode =  10086;
    /**
     * 检查并申请某个动态权限
     * @param activity
     */
    public static void requestPermisson(Activity activity){

        if(Build.VERSION.SDK_INT >= 23) { //6.0以上系统
            boolean result = hasPermission(activity, permissions);//判断是否已经拥有某项权限
            if (!result) {//去申请
                ActivityCompat.requestPermissions(activity, permissions, requestCode);
            }
        }
    }

    /**
     * 权限检查
     *
     * @param permissions
     * @return
     */
    public static boolean hasPermission(Context cxt , String[] permissions) {
        for (String permission : permissions) {
            if (ActivityCompat.checkSelfPermission(cxt, permission)
                    != PackageManager.PERMISSION_GRANTED) {
                return false;
            }
        }
        return true;
    }

    /**
     * 权限程序是否在manifest文件中声明了某权限
     *
     * @param permissions
     * @return
     */
    public static boolean hasPermissionForManifest(Context cxt , String[] permissions) {
        for (String permission : permissions) {
            if ((PackageManager.PERMISSION_GRANTED != cxt.getPackageManager()
                    .checkPermission(permission, cxt.getPackageName()))) {
                return false;
            }
        }
        return true;
    }
}

==> advert-1.3.3-sources.jar: com/yodo1/advert/utils/YPermissonUtils.java <==
package com.yodo1.advert.utils;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;
import android.support.v4.app.ActivityCompat;

/**
 * 权限检查及动态权限申请
 * Created by yodo1 on 2016/3/17.
 */
public class YPermissonUtils {
    private static String[] permissions = {Manifest.permission.READ_PHONE_STATE,Manifest.permission.WRITE_EXTERNAL_STORAGE };

    private static  int requestCode =  10086;
    /**
     * 检查并申请某个动态权限
     * @param activity
     */
    public static void requestPermisson(Activity activity){

        if(Build.VERSION.SDK_INT >= 23) { //6.0以上系统
            boolean result = hasPermission(activity, permissions);//判断是否已经拥有某项权限
            if (!result) {//去申请
                ActivityCompat.requestPermissions(activity, permissions, requestCode);
            }
        }
    }

    /**
     * 权限检查
     *
     * @param permissions
     * @return
     */
    public static boolean hasPermission(Context cxt , String[] permissions) {
        for (String permission : permissions) {
            if (ActivityCompat.checkSelfPermission(cxt, permission)
                    != PackageManager.PERMISSION_GRANTED) {
                return false;
            }
        }
        return true;
    }

    /**
     * 权限程序是否在manifest文件中声明了某权限
     *
     * @param permissions
     * @return
     */
    public static boolean hasPermissionForManifest(Context cxt , String[] permissions) {
        for (String permission : permissions) {
            if ((PackageManager.PERMISSION_GRANTED != cxt.getPackageManager()
                    .checkPermission(permission, cxt.getPackageName()))) {
                return false;
            }
        }
        return true;
    }
}
